#ifndef BOOST_SIMD_INCLUDE_FUNCTIONS_SCALAR_LOGICAL_NOTAND_HPP_INCLUDED
#define BOOST_SIMD_INCLUDE_FUNCTIONS_SCALAR_LOGICAL_NOTAND_HPP_INCLUDED

#include <boost/simd/boolean/include/functions/scalar/logical_notand.hpp>

#endif
